/////////////////////////////////////////////////////////////////////////////
// Name:        ProxyDialog.cpp
// Purpose:     Dialog for getting the proxy server information
// Author(s):   Atul, Ashesh
// Created:     2008-07-08
// RCS-ID:      $Id: ProxyDialog.cpp,v 1.6 2008/08/18 14:18:35 asheshv Exp $
// Copyright:   (c) EnterpriseDB
/////////////////////////////////////////////////////////////////////////////

#include "TuningTool.h"

// wxWindows headers
#include <wx/wx.h>
#include <wx/config.h>

#ifdef __WXMSW__
#include <wx/msw/registry.h>
#endif

// Application headers
#include "ProxyDialog.h"

BEGIN_EVENT_TABLE(ProxyDialog, wxDialog)
    EVT_BUTTON(wxID_OK,         ProxyDialog::OnOK)
    EVT_BUTTON(wxID_CANCEL,     ProxyDialog::OnCancel)
END_EVENT_TABLE()

ProxyDialog::ProxyDialog(wxWindow *parent, const wxString& title)
: wxDialog(parent, wxID_ANY, title)
{
    wxString http_host, http_port;

#ifdef WIN32
    // Get the proxy settings
    wxRegKey *key
       = new wxRegKey(wxT("HKEY_CURRENT_USER\\Software\\PostgreSQL\\"\
                          "TuningWizard\\"));

    if (key->Exists() && key->HasValue(wxT("HTTP proxy host")))
        key->QueryValue(wxT("HTTP proxy host"), http_host);

    if (key->Exists() && key->HasValue(wxT("HTTP proxy port")))
        key->QueryValue(wxT("HTTP proxy port"), http_port);

    delete key;
#else
    wxConfig *pConfig = new wxConfig(wxT("TuningWizard"));
    pConfig->SetRecordDefaults();
    pConfig->Read(wxT("/Proxy/host"), &http_host);
    pConfig->Read(wxT("/Proxy/port"), &http_port);
    delete pConfig;
#endif

    wxBoxSizer *mainSizer = new wxBoxSizer(wxVERTICAL);
    wxGridSizer *gridSizer = new wxFlexGridSizer(2, 4, 5, 5);

    wxStaticText *st = new wxStaticText(this, wxID_ANY, wxT("HTTP proxy"));
    gridSizer->Add(st, 0, wxALIGN_CENTER_VERTICAL);
    m_http_host = new wxTextCtrl(this, wxID_ANY, http_host, wxDefaultPosition, wxSize(200, -1));
    gridSizer->Add(m_http_host, 0, wxALIGN_CENTER_VERTICAL);
    st = new wxStaticText(this, wxID_ANY, wxT("Port"));
    gridSizer->Add(st, 0, wxALIGN_CENTER_VERTICAL);
    m_http_port = new wxTextCtrl(this, wxID_ANY, http_port, wxDefaultPosition, wxSize(40, -1));
    gridSizer->Add(m_http_port, 0, wxALIGN_CENTER_VERTICAL);

    mainSizer->Add(gridSizer, 0, wxALL, 10);

    wxSizer *buttonSizer = CreateButtonSizer(wxOK | wxCANCEL);

    mainSizer->Add(buttonSizer, 0, wxALL | wxALIGN_RIGHT, 5);

    SetSizer(mainSizer);
    mainSizer->Fit(this);
}

void ProxyDialog::OnOK(wxCommandEvent& event)
{
    // Check the ports are valid
    if (!m_http_port->IsEmpty() && !m_http_port->GetValue().IsNumber())
    {
        wxLogError(wxT("Invalid HTTP port specified."));
        m_http_port->SetFocus();
        return;
    }

    // Check that both host and port are specified
    if ((!m_http_host->IsEmpty() && m_http_port->IsEmpty()) || (m_http_host->IsEmpty() && !m_http_port->IsEmpty()))
    {
        wxLogError(wxT("Both the proxy server and port must be specified."));
        m_http_host->SetFocus();
        return;
    }
    // Store the settings
#ifdef __WXMSW__
    wxRegKey *key
        = new wxRegKey(wxT("HKEY_CURRENT_USER\\Software\\PostgreSQL\\"\
                           "TuningWizard\\"));
    if (!key->Exists())
        key->Create();

    key->SetValue(wxT("HTTP proxy host"), m_http_host->GetValue());
    key->SetValue(wxT("HTTP proxy port"), m_http_port->GetValue());

    delete key;
#else
    wxConfig *pConfig = new wxConfig(wxT("TuningWizard"));
    pConfig->Write(wxT("/Proxy/host"), m_http_host->GetValue());
    pConfig->Write(wxT("/Proxy/port"), m_http_port->GetValue());
    delete pConfig;
#endif
    this->EndModal(wxOK);
}

void ProxyDialog::OnCancel(wxCommandEvent& event)
{
    this->EndModal(wxCANCEL);
}

void ProxyDialog::GetProxy(wxString& host, wxString& port)
{
    host.Empty();
    port.Empty();
    // Get the proxy settings
#ifdef __WXMSW__
    wxRegKey *key = new wxRegKey(wxT("HKEY_CURRENT_USER\\Software\\PostgreSQL\\TuningWizard\\"));

    if (key->Exists() && key->HasValue(wxT("HTTP proxy host")))
        key->QueryValue(wxT("HTTP proxy host"), host);

    if (key->Exists() && key->HasValue(wxT("HTTP proxy port")))
        key->QueryValue(wxT("HTTP proxy port"), port);
#else
    wxConfig *pConfig = new wxConfig(wxT("TuningWizard"));
    pConfig->SetRecordDefaults();
    pConfig->Read(wxT("/Proxy/host"), &host);
    pConfig->Read(wxT("/Proxy/port"), &port);
    delete pConfig;
#endif
}
